@@ -22,12 +22,12 @@
 
 #define EXTRAICONPATH ""
 
-#define ROOT__cplusplus 202302L
+#define ROOT__cplusplus 201703L
 #if defined(__cplusplus) && (__cplusplus != ROOT__cplusplus)
 # if defined(_MSC_VER)
-#  pragma message("The C++ standard in this build does not match ROOT configuration (202302L); this might cause unexpected issues. And please make sure you are using the -Zc:__cplusplus compilation flag")
+#  pragma message("The C++ standard in this build does not match ROOT configuration (201703L); this might cause unexpected issues. And please make sure you are using the -Zc:__cplusplus compilation flag")
 # else
-#  warning "The C++ standard in this build does not match ROOT configuration (202302L); this might cause unexpected issues"
+#  warning "The C++ standard in this build does not match ROOT configuration (201703L); this might cause unexpected issues"
 # endif
 #endif
 
@@ -43,7 +43,6 @@
 #define R__USE_LIBCXX    /**/
 #define R__HAS_ATTRIBUTE_ALWAYS_INLINE /**/
 #define R__HAS_ATTRIBUTE_NOINLINE /**/
-#undef R__HAS_HARDWARE_INTERFERENCE_SIZE /**/
 #define R__USE_IMT   /**/
 #undef R__COMPLETE_MEM_TERMINATION /**/
 #undef R__HAS_CEFWEB  /**/
@@ -53,6 +52,8 @@
 #define R__HAS_ROOT7 /**/
 #undef R__LESS_INCLUDES /**/
 #define R__HAS_TBB /**/
+#define R__HARDWARE_INTERFERENCE_SIZE 64
+ /*Determined at CMake configure to be stable across all TUs*/
 
 #if defined(R__HAS_VECCORE) && defined(R__HAS_VC)
 #ifndef VECCORE_ENABLE_VC
@@ -74,4 +75,6 @@
 
 #undef R__HAS_URING /**/
 
+#define R__HAS_GEOM /**/
+
 #endif
